@@ -1732,7 +1732,7 @@ class Tablebases(object):
         if wdl > 0:
             # The position is a win or a cursed win by a threat move.
             if success == 3:
-                return 2 if wdl == 2 else 101
+                return 2 if wdl == 2 else 102
 
             # Generate all legal non-capturing pawn moves.
             for move in board.generate_legal_moves(board.pawns, ~board.occupied):
@@ -1761,9 +1761,9 @@ class Tablebases(object):
                 try:
                     v = -self.probe_dtz(board)
 
-                    if v > 0 and v + 1 < best:
-                        if v == 1 and board.is_checkmate():
-                            v = 0
+                    if v == 1 and board.is_checkmate():
+                        best = 1
+                    elif v > 0 and v + 1 < best:
                         best = v + 1
                 finally:
                     board.pop()
@@ -1826,10 +1826,12 @@ class Tablebases(object):
         |     |                  | be forced in n plies.                      |
         +-----+------------------+--------------------------------------------+
 
-        The return value can be off by one: a return value -n can mean a loss
-        in n + 1 plies and a return value +n can mean a win in n + 1 plies.
+        The return value can be off by one: a return value -n can mean a
+        losing zeroing move in in n + 1 plies and a return value +n can mean a
+        winning zeroing move in n + 1 plies.
         This is guaranteed not to happen for positions exactly on the edge of
-        the 50-move rule, so that this never impacts results of practical play.
+        the 50-move rule, so that (with some care) this never impacts the
+        result of practical play.
 
         Minmaxing the DTZ values guarantees winning a won position (and drawing
         a drawn position), because it makes progress keeping the win in hand.
