@@ -453,7 +453,7 @@ class Engine(object):
             try:
                 intval = int(token)
             except ValueError:
-                LOGGER.exception("exception parsing integer token")
+                LOGGER.exception("exception parsing integer token from info: %r", arg)
                 return
 
             for info_handler in self.info_handlers:
@@ -463,7 +463,7 @@ class Engine(object):
             try:
                 floatval = float(token)
             except ValueError:
-                LOGGER.exception("exception parsing float token")
+                LOGGER.exception("exception parsing float token from info: %r", arg)
 
             for info_handler in self.info_handlers:
                 fn(info_handler, floatval)
@@ -472,7 +472,7 @@ class Engine(object):
             try:
                 move = chess.Move.from_uci(token)
             except ValueError:
-                LOGGER.exception("exception parsing move token")
+                LOGGER.exception("exception parsing move token from info: %r", arg)
                 return
 
             for info_handler in self.info_handlers:
@@ -531,7 +531,7 @@ class Engine(object):
                 try:
                     pv.append(board.push_uci(token))
                 except ValueError:
-                    LOGGER.exception("exception parsing pv")
+                    LOGGER.exception("exception parsing pv from info: %r, position at root: %s", arg, self.board.fen())
             elif current_parameter == "multipv":
                 # Ignore multipv. It was already parsed before anything else.
                 pass
@@ -546,12 +546,12 @@ class Engine(object):
                     try:
                         score_cp = int(token)
                     except ValueError:
-                        LOGGER.exception("exception parsing score cp value")
+                        LOGGER.exception("exception parsing score cp value from info: %r", arg)
                 elif score_kind == "mate":
                     try:
                         score_mate = int(token)
                     except ValueError:
-                        LOGGER.exception("exception parsing score mate value")
+                        LOGGER.exception("exception parsing score mate value from info: %r", arg)
             elif current_parameter == "currmove":
                 handle_move_token(token, lambda handler, val: handler.currmove(val))
             elif current_parameter == "currmovenumber":
@@ -571,7 +571,7 @@ class Engine(object):
                     else:
                         refuted_by.append(board.push_uci(token))
                 except ValueError:
-                    LOGGER.exception("exception parsing refutation")
+                    LOGGER.exception("exception parsing refutation from info: %r, position at root: %s", arg, self.board.fen())
             elif current_parameter == "currline":
                 try:
                     if currline_cpunr is None:
@@ -579,7 +579,7 @@ class Engine(object):
                     else:
                         currline_moves.append(board.push_uci(token))
                 except ValueError:
-                    LOGGER.exception("exception parsing currline")
+                    LOGGER.exception("exception parsing currline from info: %r, position at root: %s", arg, self.board.fen())
             elif current_parameter == "ebf":
                 handle_float_token(token, lambda handler, val: handler.ebf(val))
 
@@ -819,9 +819,8 @@ class Engine(object):
         """
         Set up a given position.
 
-        Instead of just the final FEN, the initial FEN and all moves leading
-        up to the position will be sent, so that the engine can detect
-        repetitions.
+        Rather than just the final FEN, this will also send moves leading up to
+        position (at least as many as are relevant for repetition detection).
 
         If the position is from a new game, it is recommended to use the
         *ucinewgame* command before the *position* command.
@@ -845,12 +844,9 @@ class Engine(object):
             if not self.idle:
                 raise EngineStateException("position command while engine is busy")
 
-        builder = []
-        builder.append("position")
-
         # Take back moves to obtain the FEN at the latest pawn move or
-        # capture. Later giving the moves explicitly allows for transposition
-        # detection.
+        # capture. Sending the move history to the engine allows it to detect
+        # repetitions.
         switchyard = collections.deque()
         while board.move_stack:
             move = board.pop()
@@ -859,17 +855,24 @@ class Engine(object):
             if board.is_irreversible(move):
                 break
 
-        # Validate castling rights.
-        if not self.uci_chess960 and board.chess960:
-            if board.has_chess960_castling_rights():
-                LOGGER.error("not in UCI_Chess960 mode but position has non-standard castling rights")
+        # Lc0 works best when at least the last 8 moves are sent, regardless
+        # if they are relevant for repetition detection.
+        while board.move_stack and len(switchyard) < 8:
+            switchyard.append(board.pop())
 
-                # Just send the final FEN without transpositions in hopes
-                # that this will work.
-                while switchyard:
-                    board.push(switchyard.pop())
+        # Validate castling rights.
+        if not self.uci_chess960 and board.chess960 and board.has_chess960_castling_rights():
+            LOGGER.error("not in UCI_Chess960 mode but position has non-standard castling rights")
+
+            # Just send the final FEN without transpositions in hopes
+            # that this will work.
+            while switchyard and board.has_chess960_castling_rights():
+                board.push(switchyard.pop())
 
         # Send starting position.
+        builder = []
+        builder.append("position")
+
         if uci_variant == "chess" and board.fen() == chess.STARTING_FEN:
             builder.append("startpos")
         else:
